==> haskell-conduit-1.3.1-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit
version: 1.3.1
id: conduit-1.3.1-6D3uAvT8kdALKK7hvQZDx6
key: conduit-1.3.1-6D3uAvT8kdALKK7hvQZDx6
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Streaming data processing library.
description:
    `conduit` is a solution to the streaming data problem, allowing for production,
    transformation, and consumption of streams of data in constant memory. It is an
    alternative to lazy I\/O which guarantees deterministic resource handling.
    .
    For more information about conduit in general, and how this package in
    particular fits into the ecosystem, see [the conduit
    homepage](https://github.com/snoyberg/conduit#readme).
    .
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.
category: Data, Conduit
abi: c5eb821695b0330a2e9a710e5aecfc9b
exposed: True
exposed-modules:
    Conduit Data.Conduit Data.Conduit.Combinators
    Data.Conduit.Combinators.Stream Data.Conduit.Internal
    Data.Conduit.Internal.Fusion Data.Conduit.Internal.List.Stream
    Data.Conduit.Lift Data.Conduit.List
hidden-modules: Data.Conduit.Internal.Pipe
                Data.Conduit.Internal.Conduit Data.Conduit.Combinators.Unqualified
                Data.Streaming.FileRead Data.Streaming.Filesystem
import-dirs: /usr/lib/ghc-8.6.1/site-local/conduit-1.3.1
library-dirs: /usr/lib/ghc-8.6.1/site-local/conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/conduit-1.3.1
hs-libraries: HSconduit-1.3.1-6D3uAvT8kdALKK7hvQZDx6
depends:
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    exceptions-0.10.0-6rXXyfyq3lH6yULL2y1jk1 filepath-1.4.2.1
    mono-traversable-1.0.9.0-Hc8ORwljWaVBcUzSGttrSA mtl-2.2.2
    primitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf
    resourcet-1.2.2-7SmEWRXBHDlH0TaQ0yVI69 text-1.2.3.1
    transformers-0.5.5.0 unix-2.7.2.2
    unliftio-core-0.1.2.0-6l4GP0ylCTM6crlVTDgRiK
    vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
haddock-interfaces: /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html: /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-1.3.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit
version: 1.3.1
id: conduit-1.3.1-7nGkXAHpHom9EMlfdTpJwN
key: conduit-1.3.1-7nGkXAHpHom9EMlfdTpJwN
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: http://github.com/snoyberg/conduit
synopsis: Streaming data processing library.
description:
    `conduit` is a solution to the streaming data problem, allowing for production,
    transformation, and consumption of streams of data in constant memory. It is an
    alternative to lazy I\/O which guarantees deterministic resource handling.
    .
    For more information about conduit in general, and how this package in
    particular fits into the ecosystem, see [the conduit
    homepage](https://github.com/snoyberg/conduit#readme).
    .
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/conduit>.
category: Data, Conduit
abi: 574513587a7294f438fb4700b323fa2e
exposed: True
exposed-modules:
    Conduit Data.Conduit Data.Conduit.Combinators
    Data.Conduit.Combinators.Stream Data.Conduit.Internal
    Data.Conduit.Internal.Fusion Data.Conduit.Internal.List.Stream
    Data.Conduit.Lift Data.Conduit.List
hidden-modules: Data.Conduit.Internal.Pipe
                Data.Conduit.Internal.Conduit Data.Conduit.Combinators.Unqualified
                Data.Streaming.FileRead Data.Streaming.Filesystem
import-dirs: /usr/lib/ghc-8.6.2/site-local/conduit-1.3.1
library-dirs: /usr/lib/ghc-8.6.2/site-local/conduit-1.3.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/conduit-1.3.1
hs-libraries: HSconduit-1.3.1-7nGkXAHpHom9EMlfdTpJwN
depends:
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    exceptions-0.10.0-9c5BjQipUdiGeORB8copQH filepath-1.4.2.1
    mono-traversable-1.0.9.0-AsgwM060RdkLSlVPJyqiZ0 mtl-2.2.2
    primitive-0.6.4.0-1mvPxVOk6Q6KOkWCZxqESf
    resourcet-1.2.2-841yAQBgNwO7J9O4S3A6Ce text-1.2.3.1
    transformers-0.5.5.0 unix-2.7.2.2
    unliftio-core-0.1.2.0-6l4GP0ylCTM6crlVTDgRiK
    vector-0.12.0.1-BKWaeB2IPwRDyZEP11mv5m
haddock-interfaces: /usr/share/doc/haskell-conduit/html/conduit.haddock
haddock-html: /usr/share/doc/haskell-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
